@@ -4,6 +4,7 @@ from .commands import make_project
 from .commands import remove_poetry
 from .commands import work
 from .commands import write_env_file
+from .commands import setup_postgres
 
 
 def get_app():
@@ -19,6 +20,7 @@ def get_app():
     app.command(name="work")(work)
     app.command(name="remove-poetry")(remove_poetry)
     app.command(name="write-env")(write_env_file)
+    app.command(name="setup-pg")(setup_postgres)
     return app
 
 
